|wk_logo| wanikani_api
========================================

.. |wk_logo| image:: https://discourse-cdn-sjc1.com/business5/uploads/wanikani_community/original/3X/7/a/7a2bd7e8dcf8d7766b51a77960d86949215c830c.png?v=5
    :target: https://wanikani.com
    :width: 56
    :height: 56
    :align: middle

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   client
   datatypes
   exceptions
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
